# Pop


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**code** | **str** | the three-letter code for the [POP](https://developer.fastly.com/learning/concepts/pop/) | 
**name** | **str** | the name of the POP | 
**group** | **str** |  | 
**region** | **str** |  | 
**stats_region** | **str** | the region used for stats reporting | 
**billing_region** | **str** | the region used for billing | 
**coordinates** | [**PopCoordinates**](PopCoordinates.md) |  | [optional] 
**shield** | **str** | the name of the [shield code](https://developer.fastly.com/learning/concepts/shielding/#choosing-a-shield-location) if this POP is suitable for shielding | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


